==> pipewire-docs-1:1.4.9-2-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreeindex16.js <==
var NAVTREEINDEX16 =
{
"h264_8h.html":[8,9,7,47],
"hook_8h.html":[8,9,8,4,0],
"hook_8h.html":[8,9,8,5,0],
"iec958-types_8h.html":[8,9,7,10],
"iec958_8h.html":[8,9,7,11],
"impl-client_8h.html":[8,6,0,0],
"impl-core_8h.html":[8,6,1,0],
"impl-device_8h.html":[8,6,2,0],
"impl-factory_8h.html":[8,6,3,0],
"impl-interfaces_8h.html":[8,8,4,1],
"impl-link_8h.html":[8,6,4,0],
"impl-metadata_8h.html":[8,6,5,0],
"impl-module_8h.html":[8,6,6,0],
"impl-node_8h.html":[8,6,7,0],
"impl-port_8h.html":[8,6,8,0],
"impl_8h.html":[8,6,17],
"index.html":[],
"interfaces_8h.html":[8,8,4,2],
"internal_8c-example.html":[10,23],
"introspect-funcs_8h.html":[8,8,4,4],
"introspect_8h.html":[8,8,4,3],
"io_8h.html":[8,9,6,2],
"iter_8h.html":[8,9,0,5],
"json-core_8h.html":[8,9,8,6,0],
"json-pod_8h.html":[8,9,8,7,0],
"json_8h.html":[8,9,8,6,1],
"latency-types_8h.html":[8,9,7,29],
"latency_8h.html":[8,9,7,30],
"layout_8h.html":[8,9,7,12],
"link_8h.html":[8,5,7,0],
"list_8h.html":[8,9,8,3,0],
"local-v4l2_8c-example.html":[10,29],
"log-impl_8h.html":[8,9,9,3,0],
"main-loop_8h.html":[8,5,1,0],
"map_8h.html":[8,7,4,0],
"meta_8h.html":[8,9,1,2],
"metadata_8h.html":[8,8,1,0],
"midi-src_8c-example.html":[10,22],
"mjpg_8h.html":[8,9,7,48],
"module_8h.html":[8,5,9,0],
"monitor_2event_8h.html":[8,9,4,1],
"monitor_2type-info_8h.html":[8,9,4,2],
"mp3-types_8h.html":[8,9,7,13],
"mp3_8h.html":[8,9,7,14],
"multiview_8h.html":[8,9,7,49],
"names_8h.html":[8,9,8,9,0],
"node_2command_8h.html":[8,9,6,0],
"node_2event_8h.html":[8,9,6,1],
"node_2type-info_8h.html":[8,9,6,5],
"opus_8h.html":[8,9,7,15],
"page_access.html":[5,2],
"page_api.html":[6],
"page_audio.html":[5,1],
"page_client_impl.html":[6,1],
"page_client_impl.html#sec_page_client_impl_credentials":[6,1,1],
"page_client_impl.html#sec_page_client_impl_overview":[6,1,0],
"page_client_impl.html#sec_page_client_impl_resources":[6,1,3],
"page_client_impl.html#sec_page_client_impl_types":[6,1,2],
"page_config.html":[1],
"page_config_xref.html":[1,0],
"page_daemon.html":[5,10],
"page_design.html":[5,0],
"page_dma_buf.html":[5,7],
"page_examples.html":[7,6],
"page_internals.html":[5],
"page_library.html":[5,6],
"page_man_libpipewire-modules_7.html":[1,8],
"page_man_pipewire-client_conf_5.html":[1,2],
"page_man_pipewire-client_conf_5.html#client-env__environment_variables":[1,2,5],
"page_man_pipewire-client_conf_5.html#client_conf__alsa_client_properties":[1,2,3],
"page_man_pipewire-client_conf_5.html#client_conf__alsa_client_rules":[1,2,4],
"page_man_pipewire-client_conf_5.html#client_conf__configuration_file_sections":[1,2,0],
"page_man_pipewire-client_conf_5.html#client_conf__stream_properties":[1,2,1],
"page_man_pipewire-client_conf_5.html#client_conf__stream_rules":[1,2,2],
"page_man_pipewire-filter-chain_conf_5.html":[1,5],
"page_man_pipewire-jack_conf_5.html":[1,4],
"page_man_pipewire-jack_conf_5.html#jack-env__environment_variables":[1,4,3],
"page_man_pipewire-jack_conf_5.html#jack_conf__configuration_file_sections":[1,4,0],
"page_man_pipewire-jack_conf_5.html#jack_conf__jack_properties":[1,4,1],
"page_man_pipewire-jack_conf_5.html#jack_conf__match_rules":[1,4,2],
"page_man_pipewire-props_7.html":[1,6],
"page_man_pipewire-props_7.html#pipewire-props__index":[1,6,11],
"page_man_pipewire-props_7.html#props__alsa_card_profiles":[1,6,9],
"page_man_pipewire-props_7.html#props__alsa_properties":[1,6,3],
"page_man_pipewire-props_7.html#props__audio_adapter_properties":[1,6,2],
"page_man_pipewire-props_7.html#props__bluetooth_properties":[1,6,4],
"page_man_pipewire-props_7.html#props__classifying_properties":[1,6,1,1],
"page_man_pipewire-props_7.html#props__client_properties":[1,6,7],
"page_man_pipewire-props_7.html#props__common_device_properties":[1,6,0],
"page_man_pipewire-props_7.html#props__common_node_properties":[1,6,1],
"page_man_pipewire-props_7.html#props__identifying_properties":[1,6,1,0],
"page_man_pipewire-props_7.html#props__link_properties":[1,6,6],
"page_man_pipewire-props_7.html#props__other_object_types":[1,6,10],
"page_man_pipewire-props_7.html#props__port_properties":[1,6,5],
"page_man_pipewire-props_7.html#props__runtime_settings":[1,6,8],
"page_man_pipewire-props_7.html#props__scheduling_properties":[1,6,1,2],
"page_man_pipewire-props_7.html#props__session_manager_properties":[1,6,1,3],
"page_man_pipewire-pulse-modules_7.html":[1,7],
"page_man_pipewire-pulse_1.html":[2,1],
"page_man_pipewire-pulse_conf_5.html":[1,3],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__configuration_file_sections":[1,3,0],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_commands":[1,3,5],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_modules":[1,3,6],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_properties":[1,3,3],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_rules":[1,3,4],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__stream_properties":[1,3,1],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__stream_rules":[1,3,2],
"page_man_pipewire_1.html":[2,0],
"page_man_pipewire_1.html#pipewire-env__environment_variables":[2,0,1],
"page_man_pipewire_1.html#pipewire__runtime_settings":[2,0,0],
"page_man_pipewire_conf_5.html":[1,1],
"page_man_pipewire_conf_5.html#pipewire_conf__command_execution":[1,1,7],
"page_man_pipewire_conf_5.html#pipewire_conf__configuration_file_format":[1,1,1],
"page_man_pipewire_conf_5.html#pipewire_conf__configuration_file_sections":[1,1,2],
"page_man_pipewire_conf_5.html#pipewire_conf__context_objects":[1,1,6],
"page_man_pipewire_conf_5.html#pipewire_conf__context_properties":[1,1,3],
"page_man_pipewire_conf_5.html#pipewire_conf__context_properties_rules":[1,1,9],
"page_man_pipewire_conf_5.html#pipewire_conf__device_rules":[1,1,11],
"page_man_pipewire_conf_5.html#pipewire_conf__drop-in_configuration_files":[1,1,0],
"page_man_pipewire_conf_5.html#pipewire_conf__match_rules":[1,1,8],
"page_man_pipewire_conf_5.html#pipewire_conf__modules":[1,1,5],
"page_man_pipewire_conf_5.html#pipewire_conf__node_rules":[1,1,10],
"page_man_pipewire_conf_5.html#pipewire_conf__spa_libraries":[1,1,4],
"page_man_pw-cat_1.html":[2,2],
"page_man_pw-cli_1.html":[2,3],
"page_man_pw-config_1.html":[2,4],
"page_man_pw-container_1.html":[2,5],
"page_man_pw-dot_1.html":[2,6],
"page_man_pw-dump_1.html":[2,7],
"page_man_pw-jack_1.html":[2,8],
"page_man_pw-link_1.html":[2,9],
"page_man_pw-loopback_1.html":[2,10],
"page_man_pw-metadata_1.html":[2,11],
"page_man_pw-mididump_1.html":[2,12],
"page_man_pw-mon_1.html":[2,13],
"page_man_pw-profiler_1.html":[2,14],
"page_man_pw-reserve_1.html":[2,15],
"page_man_pw-top_1.html":[2,16],
"page_man_pw-v4l2_1.html":[2,17],
"page_man_spa-acp-tool_1.html":[2,18],
"page_man_spa-inspect_1.html":[2,19],
"page_man_spa-json-dump_1.html":[2,20],
"page_man_spa-monitor_1.html":[2,21],
"page_man_spa-resample_1.html":[2,22],
"page_midi.html":[5,4],
"page_module_access.html":[3,0],
"page_module_adapter.html":[3,1],
"page_module_avb.html":[3,2],
"page_module_client_device.html":[3,3],
"page_module_client_node.html":[3,4],
"page_module_combine_stream.html":[3,5],
"page_module_echo_cancel.html":[3,6],
"page_module_example_filter.html":[3,7],
"page_module_example_sink.html":[3,8],
"page_module_example_source.html":[3,9],
"page_module_fallback_sink.html":[3,10],
"page_module_ffado_driver.html":[3,11],
"page_module_filter_chain.html":[3,12],
"page_module_jack_tunnel.html":[3,14],
"page_module_jackdbus_detect.html":[3,13],
"page_module_link_factory.html":[3,15],
"page_module_loopback.html":[3,16],
"page_module_metadata.html":[3,17],
"page_module_netjack2_driver.html":[3,18],
"page_module_netjack2_manager.html":[3,19],
"page_module_parametric_equalizer.html":[3,20],
"page_module_pipe_tunnel.html":[3,21],
"page_module_portal.html":[3,22],
"page_module_profiler.html":[3,23],
"page_module_protocol_native.html":[3,24],
"page_module_protocol_pulse.html":[3,25],
"page_module_protocol_simple.html":[3,26],
"page_module_pulse_tunnel.html":[3,27],
"page_module_raop_discover.html":[3,29],
"page_module_raop_sink.html":[3,28],
"page_module_roc_sink.html":[3,30],
"page_module_roc_source.html":[3,31],
"page_module_rt.html":[3,36],
"page_module_rtp_sap.html":[3,32],
"page_module_rtp_session.html":[3,35],
"page_module_rtp_sink.html":[3,33],
"page_module_rtp_source.html":[3,34],
"page_module_session_manager.html":[3,41],
"page_module_snapcast_discover.html":[3,42],
"page_module_spa_device.html":[3,39],
"page_module_spa_device_factory.html":[3,40],
"page_module_spa_node.html":[3,37],
"page_module_spa_node_factory.html":[3,38],
"page_module_vban_recv.html":[3,43],
"page_module_vban_send.html":[3,44],
"page_module_x11_bell.html":[3,45],
"page_module_zeroconf_discover.html":[3,46],
"page_modules.html":[3],
"page_native_protocol.html":[5,9],
"page_native_protocol.html#native-protocol-client":[5,9,4],
"page_native_protocol.html#native-protocol-clientnode":[5,9,11],
"page_native_protocol.html#native-protocol-core":[5,9,2],
"page_native_protocol.html#native-protocol-device":[5,9,5],
"page_native_protocol.html#native-protocol-factory":[5,9,6],
"page_native_protocol.html#native-protocol-footer":[5,9,14],
"page_native_protocol.html#native-protocol-link":[5,9,7],
"page_native_protocol.html#native-protocol-making-connection":[5,9,1],
"page_native_protocol.html#native-protocol-message-header":[5,9,0],
"page_native_protocol.html#native-protocol-metadata":[5,9,12],
"page_native_protocol.html#native-protocol-module":[5,9,8],
"page_native_protocol.html#native-protocol-node":[5,9,9],
"page_native_protocol.html#native-protocol-port":[5,9,10],
"page_native_protocol.html#native-protocol-profiler":[5,9,13],
"page_native_protocol.html#native-protocol-registry":[5,9,3],
"page_native_protocol.html#native-protocol-registry-generation":[5,9,15],
"page_objects_design.html":[5,5],
"page_overview.html":[0],
"page_portal.html":[5,3],
"page_programs.html":[2],
"page_proxy.html":[6,2],
"page_proxy.html#sec_page_proxy_bind":[6,2,3],
"page_proxy.html#sec_page_proxy_core":[6,2,1],
"page_proxy.html#sec_page_proxy_create":[6,2,2],
"page_proxy.html#sec_page_proxy_destroy":[6,2,6],
"page_proxy.html#sec_page_proxy_events":[6,2,5],
"page_proxy.html#sec_page_proxy_methods":[6,2,4],
"page_proxy.html#sec_page_proxy_overview":[6,2,0],
"page_pulse_module_alsa_sink.html":[4,0],
"page_pulse_module_alsa_source.html":[4,1],
"page_pulse_module_always_sink.html":[4,2],
"page_pulse_module_combine_sink.html":[4,3],
"page_pulse_module_device_manager.html":[4,4],
"page_pulse_module_device_restore.html":[4,5],
"page_pulse_module_echo_cancel.html":[4,6],
"page_pulse_module_gsettings.html":[4,7],
"page_pulse_module_jackdbus_detect.html":[4,8],
"page_pulse_module_ladspa_sink.html":[4,9],
"page_pulse_module_ladspa_source.html":[4,10],
"page_pulse_module_loopback.html":[4,11],
"page_pulse_module_native_protocol_tcp.html":[4,12],
"page_pulse_module_null_sink.html":[4,13],
"page_pulse_module_pipe_sink.html":[4,14],
"page_pulse_module_pipe_source.html":[4,15],
"page_pulse_module_raop_discover.html":[4,16],
"page_pulse_module_remap_sink.html":[4,17],
"page_pulse_module_remap_source.html":[4,18],
"page_pulse_module_roc_sink.html":[4,19],
"page_pulse_module_roc_sink_input.html":[4,20],
"page_pulse_module_roc_source.html":[4,21],
"page_pulse_module_rtp_recv.html":[4,22],
"page_pulse_module_rtp_send.html":[4,23],
"page_pulse_module_simple_protocol_tcp.html":[4,24],
"page_pulse_module_stream_restore.html":[4,25],
"page_pulse_module_switch_on_connect.html":[4,26],
"page_pulse_module_tunnel_sink.html":[4,27]
};

==> pipewire-docs-1:1.4.10-2-x86_64.pkg.tar.zst: usr/share/doc/pipewire/html/navtreeindex16.js <==
var NAVTREEINDEX16 =
{
"group__spa__utils__defs.html#gaf9f1e071334f25ea8580f2509d17fcdd":[8,9,8,1,44],
"group__spa__utils__defs.html#gafa109f3532687323c8f8340f18a15220":[8,9,8,1,85],
"group__spa__utils__defs.html#gafa5449ce6a2352b7966fa923892a46fa":[8,9,8,1,78],
"group__spa__utils__defs.html#gafd41067bab5e0c66b38886f672702dd4":[8,9,8,1,23],
"group__spa__utils__defs.html#gafdcbf720fb6f9ab8a91a0eacdbc3beca":[8,9,8,1,50],
"group__spa__utils__defs.html#gafdd52836cf3dfdc12328615ac44c18e0":[8,9,8,1,14],
"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1a48000c4ffb67d7fcba31225d2ca9600d":[8,9,8,1,6,0],
"group__spa__utils__defs.html#gga9f2fae4a58cc2e3fdf568d1afc9dc7c1ad27b9a94c88677dfa8681ec43abac456":[8,9,8,1,6,1],
"h264_8h.html":[8,9,7,47],
"hook_8h.html":[8,9,8,4,0],
"hook_8h.html":[8,9,8,5,0],
"iec958-types_8h.html":[8,9,7,10],
"iec958_8h.html":[8,9,7,11],
"impl-client_8h.html":[8,6,0,0],
"impl-core_8h.html":[8,6,1,0],
"impl-device_8h.html":[8,6,2,0],
"impl-factory_8h.html":[8,6,3,0],
"impl-interfaces_8h.html":[8,8,4,1],
"impl-link_8h.html":[8,6,4,0],
"impl-metadata_8h.html":[8,6,5,0],
"impl-module_8h.html":[8,6,6,0],
"impl-node_8h.html":[8,6,7,0],
"impl-port_8h.html":[8,6,8,0],
"impl_8h.html":[8,6,18],
"index.html":[],
"interfaces_8h.html":[8,8,4,2],
"internal_8c-example.html":[10,23],
"introspect-funcs_8h.html":[8,8,4,4],
"introspect_8h.html":[8,8,4,3],
"io_8h.html":[8,9,6,2],
"iter_8h.html":[8,9,0,5],
"json-core_8h.html":[8,9,8,6,0],
"json-pod_8h.html":[8,9,8,7,0],
"json_8h.html":[8,9,8,6,1],
"latency-types_8h.html":[8,9,7,29],
"latency_8h.html":[8,9,7,30],
"layout_8h.html":[8,9,7,12],
"link_8h.html":[8,5,7,0],
"list_8h.html":[8,9,8,3,0],
"local-v4l2_8c-example.html":[10,29],
"log-impl_8h.html":[8,9,9,3,0],
"main-loop_8h.html":[8,5,1,0],
"map_8h.html":[8,7,4,0],
"meta_8h.html":[8,9,1,2],
"metadata_8h.html":[8,8,1,0],
"midi-src_8c-example.html":[10,22],
"mjpg_8h.html":[8,9,7,48],
"module_8h.html":[8,5,9,0],
"monitor_2event_8h.html":[8,9,4,1],
"monitor_2type-info_8h.html":[8,9,4,2],
"mp3-types_8h.html":[8,9,7,13],
"mp3_8h.html":[8,9,7,14],
"multiview_8h.html":[8,9,7,49],
"names_8h.html":[8,9,8,9,0],
"node_2command_8h.html":[8,9,6,0],
"node_2event_8h.html":[8,9,6,1],
"node_2type-info_8h.html":[8,9,6,5],
"opus_8h.html":[8,9,7,15],
"page_access.html":[5,2],
"page_api.html":[6],
"page_audio.html":[5,1],
"page_client_impl.html":[6,1],
"page_client_impl.html#sec_page_client_impl_credentials":[6,1,1],
"page_client_impl.html#sec_page_client_impl_overview":[6,1,0],
"page_client_impl.html#sec_page_client_impl_resources":[6,1,3],
"page_client_impl.html#sec_page_client_impl_types":[6,1,2],
"page_config.html":[1],
"page_config_xref.html":[1,0],
"page_daemon.html":[5,10],
"page_design.html":[5,0],
"page_dma_buf.html":[5,7],
"page_examples.html":[7,6],
"page_internals.html":[5],
"page_library.html":[5,6],
"page_man_libpipewire-modules_7.html":[1,8],
"page_man_pipewire-client_conf_5.html":[1,2],
"page_man_pipewire-client_conf_5.html#client-env__environment_variables":[1,2,5],
"page_man_pipewire-client_conf_5.html#client_conf__alsa_client_properties":[1,2,3],
"page_man_pipewire-client_conf_5.html#client_conf__alsa_client_rules":[1,2,4],
"page_man_pipewire-client_conf_5.html#client_conf__configuration_file_sections":[1,2,0],
"page_man_pipewire-client_conf_5.html#client_conf__stream_properties":[1,2,1],
"page_man_pipewire-client_conf_5.html#client_conf__stream_rules":[1,2,2],
"page_man_pipewire-filter-chain_conf_5.html":[1,5],
"page_man_pipewire-jack_conf_5.html":[1,4],
"page_man_pipewire-jack_conf_5.html#jack-env__environment_variables":[1,4,3],
"page_man_pipewire-jack_conf_5.html#jack_conf__configuration_file_sections":[1,4,0],
"page_man_pipewire-jack_conf_5.html#jack_conf__jack_properties":[1,4,1],
"page_man_pipewire-jack_conf_5.html#jack_conf__match_rules":[1,4,2],
"page_man_pipewire-props_7.html":[1,6],
"page_man_pipewire-props_7.html#pipewire-props__index":[1,6,11],
"page_man_pipewire-props_7.html#props__alsa_card_profiles":[1,6,9],
"page_man_pipewire-props_7.html#props__alsa_properties":[1,6,3],
"page_man_pipewire-props_7.html#props__audio_adapter_properties":[1,6,2],
"page_man_pipewire-props_7.html#props__bluetooth_properties":[1,6,4],
"page_man_pipewire-props_7.html#props__classifying_properties":[1,6,1,1],
"page_man_pipewire-props_7.html#props__client_properties":[1,6,7],
"page_man_pipewire-props_7.html#props__common_device_properties":[1,6,0],
"page_man_pipewire-props_7.html#props__common_node_properties":[1,6,1],
"page_man_pipewire-props_7.html#props__identifying_properties":[1,6,1,0],
"page_man_pipewire-props_7.html#props__link_properties":[1,6,6],
"page_man_pipewire-props_7.html#props__other_object_types":[1,6,10],
"page_man_pipewire-props_7.html#props__port_properties":[1,6,5],
"page_man_pipewire-props_7.html#props__runtime_settings":[1,6,8],
"page_man_pipewire-props_7.html#props__scheduling_properties":[1,6,1,2],
"page_man_pipewire-props_7.html#props__session_manager_properties":[1,6,1,3],
"page_man_pipewire-pulse-modules_7.html":[1,7],
"page_man_pipewire-pulse_1.html":[2,1],
"page_man_pipewire-pulse_conf_5.html":[1,3],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__configuration_file_sections":[1,3,0],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_commands":[1,3,5],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_modules":[1,3,6],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_properties":[1,3,3],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__pulseaudio_rules":[1,3,4],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__stream_properties":[1,3,1],
"page_man_pipewire-pulse_conf_5.html#pipewire-pulse_conf__stream_rules":[1,3,2],
"page_man_pipewire_1.html":[2,0],
"page_man_pipewire_1.html#pipewire-env__environment_variables":[2,0,1],
"page_man_pipewire_1.html#pipewire__runtime_settings":[2,0,0],
"page_man_pipewire_conf_5.html":[1,1],
"page_man_pipewire_conf_5.html#pipewire_conf__command_execution":[1,1,7],
"page_man_pipewire_conf_5.html#pipewire_conf__configuration_file_format":[1,1,1],
"page_man_pipewire_conf_5.html#pipewire_conf__configuration_file_sections":[1,1,2],
"page_man_pipewire_conf_5.html#pipewire_conf__context_objects":[1,1,6],
"page_man_pipewire_conf_5.html#pipewire_conf__context_properties":[1,1,3],
"page_man_pipewire_conf_5.html#pipewire_conf__context_properties_rules":[1,1,9],
"page_man_pipewire_conf_5.html#pipewire_conf__device_rules":[1,1,11],
"page_man_pipewire_conf_5.html#pipewire_conf__drop-in_configuration_files":[1,1,0],
"page_man_pipewire_conf_5.html#pipewire_conf__match_rules":[1,1,8],
"page_man_pipewire_conf_5.html#pipewire_conf__modules":[1,1,5],
"page_man_pipewire_conf_5.html#pipewire_conf__node_rules":[1,1,10],
"page_man_pipewire_conf_5.html#pipewire_conf__spa_libraries":[1,1,4],
"page_man_pw-cat_1.html":[2,2],
"page_man_pw-cli_1.html":[2,3],
"page_man_pw-config_1.html":[2,4],
"page_man_pw-container_1.html":[2,5],
"page_man_pw-dot_1.html":[2,6],
"page_man_pw-dump_1.html":[2,7],
"page_man_pw-jack_1.html":[2,8],
"page_man_pw-link_1.html":[2,9],
"page_man_pw-loopback_1.html":[2,10],
"page_man_pw-metadata_1.html":[2,11],
"page_man_pw-mididump_1.html":[2,12],
"page_man_pw-mon_1.html":[2,13],
"page_man_pw-profiler_1.html":[2,14],
"page_man_pw-reserve_1.html":[2,15],
"page_man_pw-top_1.html":[2,16],
"page_man_pw-v4l2_1.html":[2,17],
"page_man_spa-acp-tool_1.html":[2,18],
"page_man_spa-inspect_1.html":[2,19],
"page_man_spa-json-dump_1.html":[2,20],
"page_man_spa-monitor_1.html":[2,21],
"page_man_spa-resample_1.html":[2,22],
"page_midi.html":[5,4],
"page_module_access.html":[3,0],
"page_module_adapter.html":[3,1],
"page_module_avb.html":[3,2],
"page_module_client_device.html":[3,3],
"page_module_client_node.html":[3,4],
"page_module_combine_stream.html":[3,5],
"page_module_echo_cancel.html":[3,6],
"page_module_example_filter.html":[3,7],
"page_module_example_sink.html":[3,8],
"page_module_example_source.html":[3,9],
"page_module_fallback_sink.html":[3,10],
"page_module_ffado_driver.html":[3,11],
"page_module_filter_chain.html":[3,12],
"page_module_jack_tunnel.html":[3,14],
"page_module_jackdbus_detect.html":[3,13],
"page_module_link_factory.html":[3,15],
"page_module_loopback.html":[3,16],
"page_module_metadata.html":[3,17],
"page_module_netjack2_driver.html":[3,18],
"page_module_netjack2_manager.html":[3,19],
"page_module_parametric_equalizer.html":[3,20],
"page_module_pipe_tunnel.html":[3,21],
"page_module_portal.html":[3,22],
"page_module_profiler.html":[3,23],
"page_module_protocol_native.html":[3,24],
"page_module_protocol_pulse.html":[3,25],
"page_module_protocol_simple.html":[3,26],
"page_module_pulse_tunnel.html":[3,27],
"page_module_raop_discover.html":[3,29],
"page_module_raop_sink.html":[3,28],
"page_module_roc_sink.html":[3,30],
"page_module_roc_source.html":[3,31],
"page_module_rt.html":[3,36],
"page_module_rtp_sap.html":[3,32],
"page_module_rtp_session.html":[3,35],
"page_module_rtp_sink.html":[3,33],
"page_module_rtp_source.html":[3,34],
"page_module_session_manager.html":[3,41],
"page_module_snapcast_discover.html":[3,42],
"page_module_spa_device.html":[3,39],
"page_module_spa_device_factory.html":[3,40],
"page_module_spa_node.html":[3,37],
"page_module_spa_node_factory.html":[3,38],
"page_module_vban_recv.html":[3,43],
"page_module_vban_send.html":[3,44],
"page_module_x11_bell.html":[3,45],
"page_module_zeroconf_discover.html":[3,46],
"page_modules.html":[3],
"page_native_protocol.html":[5,9],
"page_native_protocol.html#native-protocol-client":[5,9,4],
"page_native_protocol.html#native-protocol-clientnode":[5,9,11],
"page_native_protocol.html#native-protocol-core":[5,9,2],
"page_native_protocol.html#native-protocol-device":[5,9,5],
"page_native_protocol.html#native-protocol-factory":[5,9,6],
"page_native_protocol.html#native-protocol-footer":[5,9,14],
"page_native_protocol.html#native-protocol-link":[5,9,7],
"page_native_protocol.html#native-protocol-making-connection":[5,9,1],
"page_native_protocol.html#native-protocol-message-header":[5,9,0],
"page_native_protocol.html#native-protocol-metadata":[5,9,12],
"page_native_protocol.html#native-protocol-module":[5,9,8],
"page_native_protocol.html#native-protocol-node":[5,9,9],
"page_native_protocol.html#native-protocol-port":[5,9,10],
"page_native_protocol.html#native-protocol-profiler":[5,9,13],
"page_native_protocol.html#native-protocol-registry":[5,9,3],
"page_native_protocol.html#native-protocol-registry-generation":[5,9,15],
"page_objects_design.html":[5,5],
"page_overview.html":[0],
"page_portal.html":[5,3],
"page_programs.html":[2],
"page_proxy.html":[6,2],
"page_proxy.html#sec_page_proxy_bind":[6,2,3],
"page_proxy.html#sec_page_proxy_core":[6,2,1],
"page_proxy.html#sec_page_proxy_create":[6,2,2],
"page_proxy.html#sec_page_proxy_destroy":[6,2,6],
"page_proxy.html#sec_page_proxy_events":[6,2,5],
"page_proxy.html#sec_page_proxy_methods":[6,2,4],
"page_proxy.html#sec_page_proxy_overview":[6,2,0],
"page_pulse_module_alsa_sink.html":[4,0],
"page_pulse_module_alsa_source.html":[4,1],
"page_pulse_module_always_sink.html":[4,2],
"page_pulse_module_combine_sink.html":[4,3],
"page_pulse_module_device_manager.html":[4,4],
"page_pulse_module_device_restore.html":[4,5],
"page_pulse_module_echo_cancel.html":[4,6],
"page_pulse_module_gsettings.html":[4,7],
"page_pulse_module_jackdbus_detect.html":[4,8],
"page_pulse_module_ladspa_sink.html":[4,9],
"page_pulse_module_ladspa_source.html":[4,10],
"page_pulse_module_loopback.html":[4,11],
"page_pulse_module_native_protocol_tcp.html":[4,12],
"page_pulse_module_null_sink.html":[4,13],
"page_pulse_module_pipe_sink.html":[4,14],
"page_pulse_module_pipe_source.html":[4,15],
"page_pulse_module_raop_discover.html":[4,16],
"page_pulse_module_remap_sink.html":[4,17],
"page_pulse_module_remap_source.html":[4,18],
"page_pulse_module_roc_sink.html":[4,19]
};
